pykeybase
===============================

Overview
--------

Python client for Keybase.io  
The main repo can be found by joining the Keybase team `mkbot`

TODO
----
* unit tests

Installation / Usage
--------------------

To install use pip:

    $ pip install pykeybase


Or clone the repo:

    $ git clone keybase://team/mkbot/pykeybase
    $ python setup.py install
    
Usage
-----
```python
import pykeybase
kb = pykeybase.KeybaseChat()
...
```
    
Contributing
------------

Please join the Keybase team `mkbot`

Example
-------

An example bot can be found in ./examples
